.. |psi| image:: https://predsci.com/doc/assets/static/psi_logo.png
   :target: https://predsci.com
   :alt: Predictive Science Inc.
   :width: 20px

.. |pypi| image:: https://img.shields.io/pypi/v/psi-io?logo=pypi&logoColor=white
   :target: https://pypi.org/project/psi-io
   :alt: PyPI

.. |license| image:: https://img.shields.io/pypi/l/psi-io?logo=apache&logoColor=white
   :target: https://opensource.org/license/apache-2-0/
   :alt: License

.. |pyversions| image:: https://img.shields.io/pypi/pyversions/psi-io.svg?logo=python&label=python&logoColor=white
   :target: https://pypi.org/project/psi-io
   :alt: Python Versions

.. |deps| image:: https://img.shields.io/librariesio/github/predsci/psi-io?logo=Libraries.io&logoColor=white
   :target: https://github.com/predsci/psi-io/blob/main/pyproject.toml
   :alt: Libraries.io

.. |publish| image:: https://github.com/predsci/psi-io/actions/workflows/publish.yml/badge.svg?
   :target: https://github.com/predsci/psi-io/actions/workflows/publish.yml
   :alt: Publish workflow

.. |docs| image:: https://github.com/predsci/psi-io/actions/workflows/docs.yml/badge.svg?
   :target: https://predsci.com/doc/psi-io
   :alt: Docs workflow

|pypi|
|license|
|pyversions|
|deps|
|publish|
|docs|

|psi| **psi-io** | *PSI's HDF Readers & Writers*
--------------------------------------------------------------------

**psi-io** is a Python package developed by `Predictive Science Inc. <https://www.predsci.com>`_ for
interacting with the PSI HDF data ecosystem. It provides a unified interface for reading and writing
HDF4 and HDF5 files, as well as tools for reading portions of datasets and interpolating data to
arbitrary positions.

To get started with **psi-io**, visit the
`User Guide <https://predsci.com/doc/psi-io/guide/>`_ for installation instructions,
an overview of features, and development/contribution guidelines; a gallery of
`examples <https://predsci.com/doc/psi-io/gallery/>`_ is also available, showcasing
various use cases and functionalities of the package. Please direct any questions or
issues to the `issue tracker <https://github.com/predsci/psi-io/issues>`_,
or `contact <https://www.predsci.com/portal/contact.php>`_ Predictive Science Inc. directly.

----

`Predictive Science Inc. <https://predsci.com>`_ |
`Repository <https://github.com/predsci/psi-io>`_ |
`Documentation <https://predsci.com/doc/psi-io>`_ |
`Distribution <https://pypi.org/project/psi-io>`_

